export declare enum HttpMethods {
    GET = "GET",
    POST = "POST",
    PUT = "PUT",
    PATCH = "PATCH",
    DELETE = "DELETE"
}
/**
 * A link to a REST resource, usually included in a HypermediaResource.
 */
export interface HypermediaLink {
    href: string;
    methods: HttpMethods[];
}
/**
 * Wrapper for HypermediaLinks taking a resource name as key und HypermediaLink as value.
 */
export type HypermediaLinks = Record<string, HypermediaLink>;
/**
 * A resource with links to other resources depending on application state and authorization of the requesting user.
 */
export interface HypermediaResource {
    _links: HypermediaLinks;
}
/**
 * The representation of a resource path. Helps to build the href in a HypermediaLink replacing path variables in a resource path.
 */
export declare class ResourcePath {
    readonly endpoint: string;
    private static readonly pathVariableRegex;
    /**
     * Group paths are existing with or without leading '/' in application context (e.g. /tenants/test or tenants/test),
     * which causes a duplicated slash in the href
     */
    private static readonly duplicatedSlashRegex;
    constructor(endpoint: string);
    href(...pathVariables: (string | number)[]): string;
}
/**
 * Evaluates user access to a resource.
 */
export interface Authorization {
    /**
     * Used for GET.
     */
    read(): boolean;
    /**
     * Simplifies POST, PUT, PATCH, DELETE to write Operations.
     */
    write(): boolean;
}
/**
 * In some use cases an explicit put access evaluation is necessary.
 */
export interface PutAuthorization {
    put(): boolean;
}
/**
 * In some use cases an explicit patch access evaluation is necessary.
 */
export interface PatchAuthorization {
    patch(): boolean;
}
/**
 * In some use cases an explicit delete access evaluation is necessary.
 */
export interface DeleteAuthorization {
    delete(): boolean;
}
/**
 * The http method builder class to provide allowed http methods for a HypermediaLink by Authorization.
 */
export declare class AuthorizedHttpMethods {
    private authorization;
    private HttpMethodss;
    constructor(authorization: Authorization);
    get(): AuthorizedHttpMethods;
    post(): AuthorizedHttpMethods;
    put(): AuthorizedHttpMethods;
    patch(): AuthorizedHttpMethods;
    delete(): AuthorizedHttpMethods;
    /**
     * Returns true if any http method is permitted.
     */
    any(): boolean;
    /**
     * Returns a copy of the current permitted http methods and resets the object.
     */
    build(): HttpMethods[];
    /**
     * Resets the object and replaces the authorization for next evaluation.
     * @param authorization
     */
    with(authorization: Authorization): AuthorizedHttpMethods;
}
