"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthorizedHttpMethods = exports.ResourcePath = exports.HttpMethods = void 0;
var HttpMethods;
(function (HttpMethods) {
    HttpMethods["GET"] = "GET";
    HttpMethods["POST"] = "POST";
    HttpMethods["PUT"] = "PUT";
    HttpMethods["PATCH"] = "PATCH";
    HttpMethods["DELETE"] = "DELETE";
})(HttpMethods || (exports.HttpMethods = HttpMethods = {}));
/**
 * The representation of a resource path. Helps to build the href in a HypermediaLink replacing path variables in a resource path.
 */
class ResourcePath {
    endpoint;
    static pathVariableRegex = new RegExp(`:([a-zA-Z()*])+`);
    /**
     * Group paths are existing with or without leading '/' in application context (e.g. /tenants/test or tenants/test),
     * which causes a duplicated slash in the href
     */
    static duplicatedSlashRegex = new RegExp(`([^:])(\\/\\/)`);
    constructor(endpoint) {
        this.endpoint = endpoint;
    }
    href(...pathVariables) {
        let href = this.endpoint;
        pathVariables.forEach((it) => (href = href.replace(ResourcePath.pathVariableRegex, it.toString()).replace(ResourcePath.duplicatedSlashRegex, `$1/`)));
        if (href.replace(`http://`, ``).replace(`https://`, ``).match(ResourcePath.pathVariableRegex)) {
            throw new Error(`Path variables replacement is incomplete, please check resource path '${href}'`);
        }
        return href;
    }
}
exports.ResourcePath = ResourcePath;
/**
 * The http method builder class to provide allowed http methods for a HypermediaLink by Authorization.
 */
class AuthorizedHttpMethods {
    authorization;
    HttpMethodss = [];
    constructor(authorization) {
        this.authorization = authorization;
    }
    get() {
        if (this.authorization.read() && !this.HttpMethodss.includes(HttpMethods.GET)) {
            this.HttpMethodss.push(HttpMethods.GET);
        }
        return this;
    }
    post() {
        if (this.authorization.write() && !this.HttpMethodss.includes(HttpMethods.POST)) {
            this.HttpMethodss.push(HttpMethods.POST);
        }
        return this;
    }
    put() {
        const isGranted = 'put' in this.authorization ? this.authorization.put() : this.authorization.write();
        if (isGranted && !this.HttpMethodss.includes(HttpMethods.PUT)) {
            this.HttpMethodss.push(HttpMethods.PUT);
        }
        return this;
    }
    patch() {
        const isGranted = 'patch' in this.authorization ? this.authorization.patch() : this.authorization.write();
        if (isGranted && !this.HttpMethodss.includes(HttpMethods.PATCH)) {
            this.HttpMethodss.push(HttpMethods.PATCH);
        }
        return this;
    }
    delete() {
        const isGranted = 'delete' in this.authorization ? this.authorization.delete() : this.authorization.write();
        if (isGranted && !this.HttpMethodss.includes(HttpMethods.DELETE)) {
            this.HttpMethodss.push(HttpMethods.DELETE);
        }
        return this;
    }
    /**
     * Returns true if any http method is permitted.
     */
    any() {
        return this.HttpMethodss.length > 0;
    }
    /**
     * Returns a copy of the current permitted http methods and resets the object.
     */
    build() {
        const methods = [...this.HttpMethodss];
        this.HttpMethodss = [];
        return methods;
    }
    /**
     * Resets the object and replaces the authorization for next evaluation.
     * @param authorization
     */
    with(authorization) {
        this.build();
        this.authorization = authorization;
        return this;
    }
}
exports.AuthorizedHttpMethods = AuthorizedHttpMethods;
//# sourceMappingURL=hateoas.model.js.map